Index: rtp.c
===================================================================
RCS file: /usr/cvsroot/asterisk/rtp.c,v
retrieving revision 1.92.2.17
diff -u -r1.92.2.17 rtp.c
--- rtp.c	1 Nov 2005 00:57:42 -0000	1.92.2.17
+++ rtp.c	23 Nov 2005 05:43:48 -0000
@@ -37,6 +37,7 @@
 #include <asterisk/config.h>
 #include <asterisk/lock.h>
 #include <asterisk/utils.h>
+#include <asterisk/cli.h>
 
 #define MAX_TIMESTAMP_SKEW	640
 
@@ -52,6 +53,7 @@
 
 static int rtpstart = 0;
 static int rtpend = 0;
+static int rtpdebug = 0;	/* Are we debugging? */
 #ifdef SO_NO_CHECK
 static int nochecksums = 0;
 #endif
@@ -248,6 +250,8 @@
 	event_end >>= 24;
 	duration = ntohl(*((unsigned int *)(data)));
 	duration &= 0xFFFF;
+	if (rtpdebug)
+		ast_log(LOG_DEBUG, "- RTP 2833 Event: %08x (len = %d)\n", event, len);
 #if 0
 	printf("Event: %08x (len = %d)\n", event, len);
 #endif	
@@ -1585,6 +1589,39 @@
 	}
 	return -1;
 }
+
+static int rtp_do_debug(int fd, int argc, char *argv[])
+{
+	if(argc != 2) {
+		return RESULT_SHOWUSAGE;
+	}
+	rtpdebug = 1;
+	ast_cli(fd, "RTP Debugging Enabled\n");
+	return RESULT_SUCCESS;
+}
+
+static int rtp_no_debug(int fd, int argc, char *argv[])
+{
+	if(argc !=3)
+		return RESULT_SHOWUSAGE;
+	rtpdebug = 0;
+	ast_cli(fd,"RTP Debugging Disabled\n");
+	return RESULT_SUCCESS;
+}
+
+static char debug_usage[] =
+  "Usage: rtp debug \n"
+  "       Enable dumping of all RTP packets to and from hosts.\n";
+
+static char no_debug_usage[] =
+  "Usage: rtp no debug\n"
+  "       Disable all RTP debugging\n";
+
+static struct ast_cli_entry  cli_debug =
+{{ "rtp", "debug", NULL } , rtp_do_debug, "Enable RTP debugging", debug_usage };
+
+static struct ast_cli_entry  cli_no_debug =
+{{ "rtp", "no", "debug", NULL } , rtp_no_debug, "Disable RTP debugging", no_debug_usage };
 
 void ast_rtp_reload(void)
 {
